@@ -1,2 +1,2 @@
-ENTRY_POINT_GROUP = 'extension_modules'
+ENTRY_POINT_GROUP = 'extensions'
 ENV_OPTION_PREFIX = 'PY_EXTENSION_BUILDER_'
